summaryrefslogtreecommitdiffstats
path: root/libk9copy/backupdlg.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libk9copy/backupdlg.cpp')
-rw-r--r--libk9copy/backupdlg.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/libk9copy/backupdlg.cpp b/libk9copy/backupdlg.cpp
index 1cc01d2..e760dfa 100644
--- a/libk9copy/backupdlg.cpp
+++ b/libk9copy/backupdlg.cpp
@@ -21,14 +21,14 @@
#include "kpushbutton.h"
/*
* Constructs a backupDlg as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-backupDlg::backupDlg( TQWidget* tqparent, const char* name, bool modal, WFlags fl )
- : TQDialog( tqparent, name, modal, fl )
+backupDlg::backupDlg( TQWidget* parent, const char* name, bool modal, WFlags fl )
+ : TQDialog( parent, name, modal, fl )
{
if ( !name )
setName( "backupDlg" );
@@ -21,14 +21,14 @@
#include "kpushbutton.h"
/*
- * Constructs a backupDlg as a child of 'tqparent', with the
+ * Constructs a backupDlg as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*